@@ -11,21 +11,24 @@ import pytest
 
 def run_pytest(*args):
     """ Run pytest and return its exit status. """
-    errno = pytest.main([
+    pytest_args = [
         '--doctest-modules',
         '--ignore=setup.py',
-        ] + list(args)
-    )
+    ] + list(args)
+    errno = pytest.main(pytest_args)
+
     return errno
 
 
 IGNORE_RECURSIVE = set([
-    '.git', 'build', 'dist', 'test', 'tests', 'venv',
+    '.git', '.tox', 'build', 'dist', 'test', 'tests', 'venv',
 ])
 
-def find_configs(repo=None):
+def find_pytest_configs(repo=None):
     """ Find dirs with pytest compatible configs. """
 
+    look_for = set(['pytest.ini', 'tox.ini'])
+
     if repo is None:
         repo = local_repo()
 
@@ -34,26 +37,31 @@ def find_configs(repo=None):
         shall_ignore = IGNORE_RECURSIVE.intersection(inside)
         return bool(shall_ignore)
 
-    look_for = set(['pytest.ini', 'tox.ini'])
     for loc, _, files in os.walk(os.path.dirname(repo.git_dir)):
         if look_for.intersection(files) and not ignore_location(loc):
             yield loc
 
 
 def pytest_setup(cmd=None):
-    """ Setup function for pytest hook(s). (Unused) """
+    """ Setup function for pytest hook(s). """
+    if cmd == 'install':
+        pass
+    elif cmd == 'uninstall':
+        pass
 
 
 def pytest_hook(*args, **kwd):
     """ Run pytest in discovered directories. """
-    locations = list(find_configs())
+    locations = list(find_pytest_configs())
+    if not locations:
+        return
     echo.bold('Will run pytest in %d dir(s).' % len(locations))
     continues = 0
     hook_return = 0
     fails = 0
     for loc in locations:
         echo.bold('->', loc)
-        returncode = run_pytest()
+        returncode = run_pytest(loc)
         if returncode:
             fails += 1
             hook_return |= returncode
